@@ -54,7 +54,7 @@ def githookA2HostingCloneUpdate(request):
         call_command('collectstatic', interactive=False)
 
         logger.debug(settings.BASE_DIR)
-        full_path_touch = os.path.join(settings.BASE_DIR, "/tmp/restart.txt")
+        full_path_touch = os.path.join(settings.BASE_DIR, "tmp/restart.txt")
         logger.debug(full_path_touch)
         Path(full_path_touch).touch()
 
@@ -103,7 +103,7 @@ def githookA2HostingRemoteUpdate(request):
         call_command('collectstatic', interactive=False)
 
         logger.debug(settings.BASE_DIR)
-        full_path_touch = os.path.join(settings.BASE_DIR, "/tmp/restart.txt")
+        full_path_touch = os.path.join(settings.BASE_DIR, "tmp/restart.txt")
         logger.debug(full_path_touch)
         Path(full_path_touch).touch()
 
